==> vst3sdk-docs-3.7.6_build_18-2-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstinterfaces/search/variables_73.js <==
var searchData=
[
  ['sampleoffset',['sampleOffset',['../../vstsdk/structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue.html#a9b2081be7783cb98c534aa1ff955ac5c',1,'Steinberg::Vst::ParameterValueQueue::ParameterQueueValue::sampleOffset()'],['../../vstsdk/structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange.html#a9b2081be7783cb98c534aa1ff955ac5c',1,'Steinberg::Vst::ParameterChangeTransfer::ParameterChange::sampleOffset()'],['../structSteinberg_1_1Vst_1_1Event.html#a9b2081be7783cb98c534aa1ff955ac5c',1,'Steinberg::Vst::Event::sampleOffset()']]],
  ['samplerate',['sampleRate',['../structSteinberg_1_1Vst_1_1ProcessSetup.html#afb7316112f9d8e74b30331957e7ca9b3',1,'Steinberg::Vst::ProcessSetup::sampleRate()'],['../structSteinberg_1_1Vst_1_1ProcessContext.html#a2bd79d2ab2dfb6aeaf75c2878ad30e1f',1,'Steinberg::Vst::ProcessContext::sampleRate()']]],
  ['samplestonextclock',['samplesToNextClock',['../structSteinberg_1_1Vst_1_1ProcessContext.html#a01be967abff36568fab07ab7d4eac7d9',1,'Steinberg::Vst::ProcessContext']]],
  ['scale',['scale',['../structSteinberg_1_1Vst_1_1Event.html#aa5ba30ca69cff19d9c45599238388230',1,'Steinberg::Vst::Event']]],
  ['scalefactor',['scaleFactor',['../../vstsdk/structVST3_1_1Hosting_1_1Module_1_1Snapshot_1_1ImageDesc.html#a7abda017cb76ae387450f3791f534046',1,'VST3::Hosting::Module::Snapshot::ImageDesc']]],
  ['sdkversion',['sdkVersion',['../../base/structSteinberg_1_1PClassInfo2.html#aefe2ed287dcf207d4f83b335ed2b78f5',1,'Steinberg::PClassInfo2::sdkVersion()'],['../../base/structSteinberg_1_1PClassInfoW.html#a2fb55f1840c1948ff8added4e4775684',1,'Steinberg::PClassInfoW::sdkVersion()'],['../../vstsdk/structVST3_1_1Hosting_1_1ClassInfo_1_1Data.html#ae705d4709a19c5cfaadd383e9203f174',1,'VST3::Hosting::ClassInfo::Data::sdkVersion()']]],
  ['sectionsize',['sectionSize',['../../vstsdk/classSteinberg_1_1Vst_1_1ReadOnlyBStream.html#af41bde84789297dfe81525f233300d84',1,'Steinberg::Vst::ReadOnlyBStream']]],
  ['seekposition',['seekPosition',['../../vstsdk/classSteinberg_1_1Vst_1_1ReadOnlyBStream.html#a1cdfa4bf0d188b0055ea2e95878cbba4',1,'Steinberg::Vst::ReadOnlyBStream']]],
  ['selectedunit',['selectedUnit',['../../vstsdk/classSteinberg_1_1Vst_1_1EditControllerEx1.html#a01ef4a1655606824bc5d406170c1f753',1,'Steinberg::Vst::EditControllerEx1']]],
  ['shorttitle',['shortTitle',['../structSteinberg_1_1Vst_1_1ParameterInfo.html#a1e6fd281b54c5303b365a179c567bdce',1,'Steinberg::Vst::ParameterInfo::shortTitle()'],['../structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo.html#a1e6fd281b54c5303b365a179c567bdce',1,'Steinberg::Vst::NoteExpressionTypeInfo::shortTitle()'],['../structSteinberg_1_1Vst_1_1KeyswitchInfo.html#a1e6fd281b54c5303b365a179c567bdce',1,'Steinberg::Vst::KeyswitchInfo::shortTitle()']]],
  ['silenceflags',['silenceFlags',['../structSteinberg_1_1Vst_1_1AudioBusBuffers.html#a2c73b926e22ddb05193b6edd16a008f8',1,'Steinberg::Vst::AudioBusBuffers']]],
  ['size',['size',['../../vstsdk/classSteinberg_1_1MemoryStream.html#ab1758d5ff5bb8a9770c8c1e1b3b5b5f9',1,'Steinberg::MemoryStream::size()'],['../../vstsdk/structSteinberg_1_1Vst_1_1PresetFile_1_1Entry.html#ab1758d5ff5bb8a9770c8c1e1b3b5b5f9',1,'Steinberg::Vst::PresetFile::Entry::size()'],['../../vstsdk/classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#aa1728750481b853c3246037c1ba1c68b',1,'Steinberg::Vst::ParameterChangeTransfer::size()'],['../structSteinberg_1_1Vst_1_1DataEvent.html#a0d40f1591c12f359c3fa3f982f9a221d',1,'Steinberg::Vst::DataEvent::size()']]],
  ['smpteoffsetsubframes',['smpteOffsetSubframes',['../structSteinberg_1_1Vst_1_1ProcessContext.html#af46e5ad510319f6dd5687519ae47c76b',1,'Steinberg::Vst::ProcessContext']]],
  ['smtg_5foverride',['SMTG_OVERRIDE',['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a985dc60099827f0160cf03e294e3989b',1,'Steinberg::Vst::SingleComponentEffect']]],
  ['sourceoffset',['sourceOffset',['../../vstsdk/classSteinberg_1_1Vst_1_1ReadOnlyBStream.html#ac307066b40cf8bf55dd44465564f3e65',1,'Steinberg::Vst::ReadOnlyBStream']]],
  ['sourcestream',['sourceStream',['../../vstsdk/classSteinberg_1_1Vst_1_1ReadOnlyBStream.html#ab5f8047e9c69ee8936a446f5de7c6cc6',1,'Steinberg::Vst::ReadOnlyBStream']]],
  ['speaker',['speaker',['../../vstsdk/classSteinberg_1_1Vst_1_1SpeakerArray.html#a46342207540a92616e060073b43f57f3',1,'Steinberg::Vst::SpeakerArray']]],
  ['srcconnection',['srcConnection',['../../vstsdk/classSteinberg_1_1Vst_1_1ConnectionProxy.html#a4487b5c458a52ed743064aad105a244d',1,'Steinberg::Vst::ConnectionProxy']]],
  ['state',['state',['../../vstsdk/classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#ab27374d05aa1aa87c6cbb4e324f0214a',1,'Steinberg::Vst::XmlRepresentationHelper::state()'],['../structSteinberg_1_1Vst_1_1ProcessContext.html#a0a213e749fd32870b11cffff1c0c2e53',1,'Steinberg::Vst::ProcessContext::state()']]],
  ['stepcount',['stepCount',['../structSteinberg_1_1Vst_1_1ParameterInfo.html#ac1efeff62e4ba9aea101c3327e0b5c4d',1,'Steinberg::Vst::ParameterInfo::stepCount()'],['../structSteinberg_1_1Vst_1_1NoteExpressionValueDescription.html#ac1efeff62e4ba9aea101c3327e0b5c4d',1,'Steinberg::Vst::NoteExpressionValueDescription::stepCount()']]],
  ['stream',['stream',['../../vstsdk/classSteinberg_1_1Vst_1_1PresetFile.html#a78d49eed9e150f042fe1e0434fb52102',1,'Steinberg::Vst::PresetFile::stream()'],['../../vstsdk/classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#a656f4750b7e015914cb070af5714edd1',1,'Steinberg::Vst::XmlRepresentationHelper::stream()']]],
  ['strings',['strings',['../../vstsdk/classSteinberg_1_1Vst_1_1StringListParameter.html#a5a9dee2a0836631d70d59cde796132a0',1,'Steinberg::Vst::StringListParameter']]],
  ['subcategories',['subCategories',['../../base/structSteinberg_1_1PClassInfo2.html#a106c76c37c57aa35e42654278412ee90',1,'Steinberg::PClassInfo2::subCategories()'],['../../base/structSteinberg_1_1PClassInfoW.html#a106c76c37c57aa35e42654278412ee90',1,'Steinberg::PClassInfoW::subCategories()'],['../../vstsdk/structVST3_1_1Hosting_1_1ClassInfo_1_1Data.html#aa58fa0abd717f05f9716d6644e4c9c27',1,'VST3::Hosting::ClassInfo::Data::subCategories()']]],
  ['symbolicsamplesize',['symbolicSampleSize',['../structSteinberg_1_1Vst_1_1ProcessSetup.html#a9392481e4890fb9c08015eed7c2655e0',1,'Steinberg::Vst::ProcessSetup::symbolicSampleSize()'],['../structSteinberg_1_1Vst_1_1ProcessData.html#a9392481e4890fb9c08015eed7c2655e0',1,'Steinberg::Vst::ProcessData::symbolicSampleSize()']]],
  ['systemtime',['systemTime',['../structSteinberg_1_1Vst_1_1ProcessContext.html#a6dca674d990cf41493918b226fcf5dde',1,'Steinberg::Vst::ProcessContext']]],
  ['systemwindow',['systemWindow',['../../vstsdk/classSteinberg_1_1CPluginView.html#a1ab25603380f1d0ae10df538fc872afd',1,'Steinberg::CPluginView']]]
];

==> vst3sdk-docs-3.7.10_build_14-1-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstinterfaces/search/variables_73.js <==
var searchData=
[
  ['sampleoffset',['sampleOffset',['../../vstsdk/structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue.html#a9b2081be7783cb98c534aa1ff955ac5c',1,'Steinberg::Vst::ParameterValueQueue::ParameterQueueValue::sampleOffset()'],['../../vstsdk/structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange.html#a9b2081be7783cb98c534aa1ff955ac5c',1,'Steinberg::Vst::ParameterChangeTransfer::ParameterChange::sampleOffset()'],['../structSteinberg_1_1Vst_1_1Event.html#a9b2081be7783cb98c534aa1ff955ac5c',1,'Steinberg::Vst::Event::sampleOffset()']]],
  ['samplerate',['sampleRate',['../structSteinberg_1_1Vst_1_1ProcessSetup.html#afb7316112f9d8e74b30331957e7ca9b3',1,'Steinberg::Vst::ProcessSetup::sampleRate()'],['../structSteinberg_1_1Vst_1_1ProcessContext.html#a2bd79d2ab2dfb6aeaf75c2878ad30e1f',1,'Steinberg::Vst::ProcessContext::sampleRate()']]],
  ['samplestonextclock',['samplesToNextClock',['../structSteinberg_1_1Vst_1_1ProcessContext.html#a01be967abff36568fab07ab7d4eac7d9',1,'Steinberg::Vst::ProcessContext']]],
  ['scale',['scale',['../structSteinberg_1_1Vst_1_1Event.html#aa5ba30ca69cff19d9c45599238388230',1,'Steinberg::Vst::Event']]],
  ['scalefactor',['scaleFactor',['../../vstsdk/structVST3_1_1Hosting_1_1Module_1_1Snapshot_1_1ImageDesc.html#a7abda017cb76ae387450f3791f534046',1,'VST3::Hosting::Module::Snapshot::ImageDesc']]],
  ['sdkversion',['sdkVersion',['../../base/structSteinberg_1_1PClassInfo2.html#aefe2ed287dcf207d4f83b335ed2b78f5',1,'Steinberg::PClassInfo2::sdkVersion()'],['../../base/structSteinberg_1_1PClassInfoW.html#a2fb55f1840c1948ff8added4e4775684',1,'Steinberg::PClassInfoW::sdkVersion()'],['../../vstsdk/structVST3_1_1Hosting_1_1ClassInfo_1_1Data.html#ae705d4709a19c5cfaadd383e9203f174',1,'VST3::Hosting::ClassInfo::Data::sdkVersion()']]],
  ['sectionsize',['sectionSize',['../../vstsdk/classSteinberg_1_1Vst_1_1ReadOnlyBStream.html#af41bde84789297dfe81525f233300d84',1,'Steinberg::Vst::ReadOnlyBStream']]],
  ['seekposition',['seekPosition',['../../vstsdk/classSteinberg_1_1Vst_1_1ReadOnlyBStream.html#a1cdfa4bf0d188b0055ea2e95878cbba4',1,'Steinberg::Vst::ReadOnlyBStream']]],
  ['selectedunit',['selectedUnit',['../../vstsdk/classSteinberg_1_1Vst_1_1EditControllerEx1.html#a01ef4a1655606824bc5d406170c1f753',1,'Steinberg::Vst::EditControllerEx1']]],
  ['shorttitle',['shortTitle',['../structSteinberg_1_1Vst_1_1ParameterInfo.html#a1e6fd281b54c5303b365a179c567bdce',1,'Steinberg::Vst::ParameterInfo::shortTitle()'],['../structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo.html#a1e6fd281b54c5303b365a179c567bdce',1,'Steinberg::Vst::NoteExpressionTypeInfo::shortTitle()'],['../structSteinberg_1_1Vst_1_1KeyswitchInfo.html#a1e6fd281b54c5303b365a179c567bdce',1,'Steinberg::Vst::KeyswitchInfo::shortTitle()']]],
  ['silenceflags',['silenceFlags',['../structSteinberg_1_1Vst_1_1AudioBusBuffers.html#a2c73b926e22ddb05193b6edd16a008f8',1,'Steinberg::Vst::AudioBusBuffers']]],
  ['size',['size',['../../vstsdk/classSteinberg_1_1MemoryStream.html#ab1758d5ff5bb8a9770c8c1e1b3b5b5f9',1,'Steinberg::MemoryStream::size()'],['../../vstsdk/structSteinberg_1_1Vst_1_1PresetFile_1_1Entry.html#ab1758d5ff5bb8a9770c8c1e1b3b5b5f9',1,'Steinberg::Vst::PresetFile::Entry::size()'],['../../vstsdk/classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#aa1728750481b853c3246037c1ba1c68b',1,'Steinberg::Vst::ParameterChangeTransfer::size()'],['../structSteinberg_1_1Vst_1_1DataExchangeBlock.html#a0d40f1591c12f359c3fa3f982f9a221d',1,'Steinberg::Vst::DataExchangeBlock::size()'],['../structSteinberg_1_1Vst_1_1DataEvent.html#a0d40f1591c12f359c3fa3f982f9a221d',1,'Steinberg::Vst::DataEvent::size()']]],
  ['smpteoffsetsubframes',['smpteOffsetSubframes',['../structSteinberg_1_1Vst_1_1ProcessContext.html#af46e5ad510319f6dd5687519ae47c76b',1,'Steinberg::Vst::ProcessContext']]],
  ['smtg_5foverride',['SMTG_OVERRIDE',['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a985dc60099827f0160cf03e294e3989b',1,'Steinberg::Vst::SingleComponentEffect']]],
  ['sourceoffset',['sourceOffset',['../../vstsdk/classSteinberg_1_1Vst_1_1ReadOnlyBStream.html#ac307066b40cf8bf55dd44465564f3e65',1,'Steinberg::Vst::ReadOnlyBStream']]],
  ['sourcestream',['sourceStream',['../../vstsdk/classSteinberg_1_1Vst_1_1ReadOnlyBStream.html#ab5f8047e9c69ee8936a446f5de7c6cc6',1,'Steinberg::Vst::ReadOnlyBStream']]],
  ['speaker',['speaker',['../../vstsdk/classSteinberg_1_1Vst_1_1SpeakerArray.html#a46342207540a92616e060073b43f57f3',1,'Steinberg::Vst::SpeakerArray']]],
  ['srcconnection',['srcConnection',['../../vstsdk/classSteinberg_1_1Vst_1_1ConnectionProxy.html#a4487b5c458a52ed743064aad105a244d',1,'Steinberg::Vst::ConnectionProxy']]],
  ['state',['state',['../../vstsdk/classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#ab27374d05aa1aa87c6cbb4e324f0214a',1,'Steinberg::Vst::XmlRepresentationHelper::state()'],['../structSteinberg_1_1Vst_1_1ProcessContext.html#a0a213e749fd32870b11cffff1c0c2e53',1,'Steinberg::Vst::ProcessContext::state()']]],
  ['stepcount',['stepCount',['../structSteinberg_1_1Vst_1_1ParameterInfo.html#ac1efeff62e4ba9aea101c3327e0b5c4d',1,'Steinberg::Vst::ParameterInfo::stepCount()'],['../structSteinberg_1_1Vst_1_1NoteExpressionValueDescription.html#ac1efeff62e4ba9aea101c3327e0b5c4d',1,'Steinberg::Vst::NoteExpressionValueDescription::stepCount()']]],
  ['stream',['stream',['../../vstsdk/classSteinberg_1_1Vst_1_1PresetFile.html#a78d49eed9e150f042fe1e0434fb52102',1,'Steinberg::Vst::PresetFile::stream()'],['../../vstsdk/classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html#a656f4750b7e015914cb070af5714edd1',1,'Steinberg::Vst::XmlRepresentationHelper::stream()']]],
  ['strings',['strings',['../../vstsdk/classSteinberg_1_1Vst_1_1StringListParameter.html#a5a9dee2a0836631d70d59cde796132a0',1,'Steinberg::Vst::StringListParameter']]],
  ['subcategories',['subCategories',['../../base/structSteinberg_1_1PClassInfo2.html#a106c76c37c57aa35e42654278412ee90',1,'Steinberg::PClassInfo2::subCategories()'],['../../base/structSteinberg_1_1PClassInfoW.html#a106c76c37c57aa35e42654278412ee90',1,'Steinberg::PClassInfoW::subCategories()'],['../../vstsdk/structVST3_1_1Hosting_1_1ClassInfo_1_1Data.html#aa58fa0abd717f05f9716d6644e4c9c27',1,'VST3::Hosting::ClassInfo::Data::subCategories()']]],
  ['symbolicsamplesize',['symbolicSampleSize',['../structSteinberg_1_1Vst_1_1ProcessSetup.html#a9392481e4890fb9c08015eed7c2655e0',1,'Steinberg::Vst::ProcessSetup::symbolicSampleSize()'],['../structSteinberg_1_1Vst_1_1ProcessData.html#a9392481e4890fb9c08015eed7c2655e0',1,'Steinberg::Vst::ProcessData::symbolicSampleSize()']]],
  ['systemtime',['systemTime',['../structSteinberg_1_1Vst_1_1ProcessContext.html#a6dca674d990cf41493918b226fcf5dde',1,'Steinberg::Vst::ProcessContext']]],
  ['systemwindow',['systemWindow',['../../vstsdk/classSteinberg_1_1CPluginView.html#a1ab25603380f1d0ae10df538fc872afd',1,'Steinberg::CPluginView']]]
];
